@@ -22,15 +22,14 @@ package cmd
 
 import (
 	"bytes"
-	"context"
 	"errors"
+	"fmt"
 	"io"
 	"io/ioutil"
 	"os"
 	"path"
 	"path/filepath"
 	"runtime"
-	"strings"
 	"testing"
 
 	"github.com/sirupsen/logrus"
@@ -134,140 +133,154 @@ func TestHandleSummaryResultError(t *testing.T) {
 	assertEqual(t, "file summary 2", files[filePath2])
 }
 
-func TestAbortTest(t *testing.T) {
+func TestRunScriptErrorsAndAbort(t *testing.T) {
 	t.Parallel()
 	testCases := []struct {
-		testFilename, expLogOutput string
+		testFilename, name   string
+		expErr, expLogOutput string
+		expExitCode          errext.ExitCode
+		extraArgs            []string
 	}{
 		{
 			testFilename: "abort.js",
+			expErr:       common.AbortTest,
+			expExitCode:  exitcodes.ScriptAborted,
 		},
 		{
 			testFilename: "abort_initerr.js",
+			expErr:       common.AbortTest,
+			expExitCode:  exitcodes.ScriptAborted,
 		},
 		{
 			testFilename: "abort_initvu.js",
+			expErr:       common.AbortTest,
+			expExitCode:  exitcodes.ScriptAborted,
 		},
 		{
 			testFilename: "abort_teardown.js",
+			expErr:       common.AbortTest,
+			expExitCode:  exitcodes.ScriptAborted,
 			expLogOutput: "Calling teardown function after test.abort()",
 		},
+		{
+			testFilename: "initerr.js",
+			expErr:       "ReferenceError: someUndefinedVar is not defined",
+			expExitCode:  exitcodes.ScriptException,
+		},
+		{
+			testFilename: "thresholds/non_existing_metric.js",
+			name:         "run should fail with exit status 104 on a threshold applied to a non existing metric",
+			expErr:       "invalid threshold",
+			expExitCode:  exitcodes.InvalidConfig,
+		},
+		{
+			testFilename: "thresholds/non_existing_metric.js",
+			name:         "run should succeed on a threshold applied to a non existing metric with the --no-thresholds flag set",
+			extraArgs:    []string{"--no-thresholds"},
+		},
+		{
+			testFilename: "thresholds/non_existing_metric.js",
+			name:         "run should succeed on a threshold applied to a non existing submetric with the --no-thresholds flag set",
+			extraArgs:    []string{"--no-thresholds"},
+		},
+		{
+			testFilename: "thresholds/malformed_expression.js",
+			name:         "run should fail with exit status 104 on a malformed threshold expression",
+			expErr:       "malformed threshold expression",
+			expExitCode:  exitcodes.InvalidConfig,
+		},
+		{
+			testFilename: "thresholds/malformed_expression.js",
+			name:         "run should on a malformed threshold expression but --no-thresholds flag set",
+			extraArgs:    []string{"--no-thresholds"},
+			// we don't expect an error
+		},
+		{
+			testFilename: "thresholds/unsupported_aggregation_method.js",
+			name:         "run should fail with exit status 104 on a threshold applying an unsupported aggregation method to a metric",
+			expErr:       "invalid threshold",
+			expExitCode:  exitcodes.InvalidConfig,
+		},
+		{
+			testFilename: "thresholds/unsupported_aggregation_method.js",
+			name:         "run should succeed on a threshold applying an unsupported aggregation method to a metric with the --no-thresholds flag set",
+			extraArgs:    []string{"--no-thresholds"},
+		},
 	}
 
 	for _, tc := range testCases {
 		tc := tc
-		t.Run(tc.testFilename, func(t *testing.T) {
+		name := tc.testFilename
+		if tc.name != "" {
+			name = fmt.Sprintf("%s (%s)", tc.testFilename, tc.name)
+		}
+		t.Run(name, func(t *testing.T) {
 			t.Parallel()
-			ctx, cancel := context.WithCancel(context.Background())
-			defer cancel()
 
-			logger := logrus.New()
-			logger.SetLevel(logrus.InfoLevel)
-			logger.Out = ioutil.Discard
-			hook := testutils.SimpleLogrusHook{
-				HookedLevels: []logrus.Level{logrus.InfoLevel},
-			}
-			logger.AddHook(&hook)
-
-			cmd := getRunCmd(ctx, logger, newCommandFlags())
-			a, err := filepath.Abs(path.Join("testdata", tc.testFilename))
+			testScript, err := ioutil.ReadFile(path.Join("testdata", tc.testFilename))
 			require.NoError(t, err)
-			cmd.SetArgs([]string{a})
-			err = cmd.Execute()
-			var e errext.HasExitCode
-			require.ErrorAs(t, err, &e)
-			assert.Equalf(t, exitcodes.ScriptAborted, e.ExitCode(),
-				"Status code must be %d", exitcodes.ScriptAborted)
-			assert.Contains(t, e.Error(), common.AbortTest)
+
+			testState := newGlobalTestState(t)
+			require.NoError(t, afero.WriteFile(testState.fs, filepath.Join(testState.cwd, tc.testFilename), testScript, 0o644))
+			testState.args = append([]string{"k6", "run", tc.testFilename}, tc.extraArgs...)
+
+			testState.expectedExitCode = int(tc.expExitCode)
+			newRootCommand(testState.globalState).execute()
+
+			logs := testState.loggerHook.Drain()
+
+			if tc.expErr != "" {
+				assert.True(t, testutils.LogContains(logs, logrus.ErrorLevel, tc.expErr))
+			}
 
 			if tc.expLogOutput != "" {
-				var gotMsg bool
-				for _, entry := range hook.Drain() {
-					if strings.Contains(entry.Message, tc.expLogOutput) {
-						gotMsg = true
-						break
-					}
-				}
-				assert.True(t, gotMsg)
+				assert.True(t, testutils.LogContains(logs, logrus.InfoLevel, tc.expLogOutput))
 			}
 		})
 	}
 }
 
-func TestInitErrExitCode(t *testing.T) {
-	t.Parallel()
-	ctx, cancel := context.WithCancel(context.Background())
-	defer cancel()
-	logger := testutils.NewLogger(t)
-
-	cmd := getRunCmd(ctx, logger, newCommandFlags())
-	a, err := filepath.Abs("testdata/initerr.js")
-	require.NoError(t, err)
-	cmd.SetArgs([]string{a})
-	err = cmd.Execute()
-	var e errext.HasExitCode
-	require.ErrorAs(t, err, &e)
-	assert.Equalf(t, exitcodes.ScriptException, e.ExitCode(),
-		"Status code must be %d", exitcodes.ScriptException)
-	assert.Contains(t, err.Error(), "ReferenceError: someUndefinedVar is not defined")
-}
-
-func TestRunThresholds(t *testing.T) {
+func TestInvalidOptionsThresholdErrExitCode(t *testing.T) {
 	t.Parallel()
 
 	testCases := []struct {
 		name         string
-		noThresholds bool
 		testFilename string
-
-		wantErr bool
+		expExitCode  errext.ExitCode
+		extraArgs    []string
 	}{
 		{
 			name:         "run should fail with exit status 104 on a malformed threshold expression",
-			noThresholds: false,
-			testFilename: "testdata/thresholds/malformed_expression.js",
-			wantErr:      true,
+			testFilename: "thresholds/malformed_expression.js",
+			expExitCode:  exitcodes.InvalidConfig,
 		},
 		{
-			name:         "run should on a malformed threshold expression but --no-thresholds flag set",
-			noThresholds: true,
-			testFilename: "testdata/thresholds/malformed_expression.js",
-			wantErr:      false,
+			name:         "run should fail with exit status 104 on a threshold applied to a non existing metric",
+			testFilename: "thresholds/non_existing_metric.js",
+			expExitCode:  exitcodes.InvalidConfig,
+		},
+		{
+			name:         "run should fail with exit status 104 on a threshold method being unsupported by the metric",
+			testFilename: "thresholds/unsupported_aggregation_method.js",
+			expExitCode:  exitcodes.InvalidConfig,
 		},
 	}
 
-	for _, testCase := range testCases {
-		testCase := testCase
-		t.Run(testCase.name, func(t *testing.T) {
+	for _, tc := range testCases {
+		tc := tc
+
+		t.Run(tc.name, func(t *testing.T) {
 			t.Parallel()
 
-			ctx, cancel := context.WithCancel(context.Background())
-			defer cancel()
-			cmd := getRunCmd(ctx, testutils.NewLogger(t), newCommandFlags())
-			filename, err := filepath.Abs(testCase.testFilename)
+			testScript, err := ioutil.ReadFile(path.Join("testdata", tc.testFilename))
 			require.NoError(t, err)
-			args := []string{filename}
-			if testCase.noThresholds {
-				args = append(args, "--no-thresholds")
-			}
-			cmd.SetArgs(args)
-			wantExitCode := exitcodes.InvalidConfig
 
-			var gotErrExt errext.HasExitCode
-			gotErr := cmd.Execute()
+			testState := newGlobalTestState(t)
+			require.NoError(t, afero.WriteFile(testState.fs, filepath.Join(testState.cwd, tc.testFilename), testScript, 0o644))
+			testState.args = append([]string{"k6", "run", tc.testFilename}, tc.extraArgs...)
 
-			assert.Equal(t,
-				testCase.wantErr,
-				gotErr != nil,
-				"run command error = %v, wantErr %v", gotErr, testCase.wantErr,
-			)
-
-			if testCase.wantErr {
-				require.ErrorAs(t, gotErr, &gotErrExt)
-				assert.Equalf(t, wantExitCode, gotErrExt.ExitCode(),
-					"status code must be %d", wantExitCode,
-				)
-			}
+			testState.expectedExitCode = int(tc.expExitCode)
+			newRootCommand(testState.globalState).execute()
 		})
 	}
 }
