@@ -21,14 +21,12 @@
 package cmd
 
 import (
-	"context"
-
 	"github.com/spf13/cobra"
 
 	"go.k6.io/k6/api/v1/client"
 )
 
-func getStatusCmd(ctx context.Context, globalFlags *commandFlags) *cobra.Command {
+func getCmdStatus(globalState *globalState) *cobra.Command {
 	// statusCmd represents the status command
 	statusCmd := &cobra.Command{
 		Use:   "status",
@@ -37,16 +35,16 @@ func getStatusCmd(ctx context.Context, globalFlags *commandFlags) *cobra.Command
 
   Use the global --address flag to specify the URL to the API server.`,
 		RunE: func(cmd *cobra.Command, args []string) error {
-			c, err := client.New(globalFlags.address)
+			c, err := client.New(globalState.flags.address)
 			if err != nil {
 				return err
 			}
-			status, err := c.Status(ctx)
+			status, err := c.Status(globalState.ctx)
 			if err != nil {
 				return err
 			}
 
-			return yamlPrint(globalFlags.stdout, status)
+			return yamlPrint(globalState.stdOut, status)
 		},
 	}
 	return statusCmd
