@@ -29,9 +29,9 @@ import (
 
 	"go.k6.io/k6/js"
 	"go.k6.io/k6/lib"
-	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/lib/testutils"
 	"go.k6.io/k6/loader"
+	"go.k6.io/k6/metrics"
 )
 
 func TestBuildK6Headers(t *testing.T) {
@@ -61,10 +61,15 @@ func TestBuildK6RequestObject(t *testing.T) {
 	assert.NoError(t, err)
 	registry := metrics.NewRegistry()
 	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
-	_, err = js.New(testutils.NewLogger(t), &loader.SourceData{
-		URL:  &url.URL{Path: "/script.js"},
-		Data: []byte(fmt.Sprintf("export default function() { res = http.batch([%v]); }", v)),
-	}, nil, lib.RuntimeOptions{}, builtinMetrics, registry)
+	_, err = js.New(
+		&lib.RuntimeState{
+			Logger:         testutils.NewLogger(t),
+			BuiltinMetrics: builtinMetrics,
+			Registry:       registry,
+		}, &loader.SourceData{
+			URL:  &url.URL{Path: "/script.js"},
+			Data: []byte(fmt.Sprintf("export default function() { res = http.batch([%v]); }", v)),
+		}, nil)
 	assert.NoError(t, err)
 }
 
