@@ -25,7 +25,6 @@ import (
 
 	"github.com/dop251/goja"
 	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
 )
 
 const testHTMLElems = `
@@ -85,16 +84,13 @@ const testHTMLElems = `
 
 func TestElements(t *testing.T) {
 	t.Parallel()
-	rt, _ := getTestModuleInstance(t)
-	require.NoError(t, rt.Set("src", testHTMLElems))
-
-	_, err := rt.RunString(`var doc = html.parseHTML(src)`)
-
-	require.NoError(t, err)
-	assert.IsType(t, Selection{}, rt.Get("doc").Export())
-
 	t.Run("AnchorElement", func(t *testing.T) {
+		t.Parallel()
+
 		t.Run("Hash", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("a").get(0).hash()`); assert.NoError(t, err) {
 				assert.Equal(t, "#hashtext", v.Export())
 			}
@@ -103,6 +99,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("Host", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("a").get(1).host()`); assert.NoError(t, err) {
 				assert.Equal(t, "example.com", v.Export())
 			}
@@ -120,6 +119,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("Hostname", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("a").get(1).hostname()`); assert.NoError(t, err) {
 				assert.Equal(t, "example.com", v.Export())
 			}
@@ -128,6 +130,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("Port", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("a").get(5).port()`); assert.NoError(t, err) {
 				assert.Equal(t, "80", v.Export())
 			}
@@ -136,6 +141,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("Username", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("a").get(5).username()`); assert.NoError(t, err) {
 				assert.Equal(t, "username", v.Export())
 			}
@@ -144,6 +152,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("Password", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("a").get(5).password()`); assert.NoError(t, err) {
 				assert.Equal(t, "password", v.Export())
 			}
@@ -152,6 +163,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("Origin", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("a").get(5).origin()`); assert.NoError(t, err) {
 				assert.Equal(t, "http://example.com:80", v.Export())
 			}
@@ -160,6 +174,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("Pathname", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("a").get(1).pathname()`); assert.NoError(t, err) {
 				assert.Equal(t, "", v.Export())
 			}
@@ -171,6 +188,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("Protocol", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("a").get(4).protocol()`); assert.NoError(t, err) {
 				assert.Equal(t, "https", v.Export())
 			}
@@ -179,6 +199,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("RelList", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("a").get(6).relList()`); assert.NoError(t, err) {
 				assert.Equal(t, []string{"prev", "next"}, v.Export())
 			}
@@ -187,23 +210,37 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("Search", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("a").get(0).search()`); assert.NoError(t, err) {
 				assert.Equal(t, "?querytxt", v.Export())
 			}
 		})
 		t.Run("Text", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("a").get(6).text()`); assert.NoError(t, err) {
 				assert.Equal(t, "6", v.Export())
 			}
 		})
 	})
 	t.Run("AreaElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		if v, err := rt.RunString(`doc.find("area").get(0).toString()`); assert.NoError(t, err) {
 			assert.Equal(t, "web.address.com", v.Export())
 		}
 	})
 	t.Run("ButtonElement", func(t *testing.T) {
+		t.Parallel()
+
 		t.Run("form", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("#form_btn").get(0).form().id()`); assert.NoError(t, err) {
 				assert.Equal(t, "form1", v.Export())
 			}
@@ -215,6 +252,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("formaction", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("#form_btn").get(0).formAction()`); assert.NoError(t, err) {
 				assert.Equal(t, "action_url", v.Export())
 			}
@@ -223,6 +263,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("formenctype", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("#form_btn").get(0).formEnctype()`); assert.NoError(t, err) {
 				assert.Equal(t, "text/plain", v.Export())
 			}
@@ -231,6 +274,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("formmethod", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("#form_btn").get(0).formMethod()`); assert.NoError(t, err) {
 				assert.Equal(t, "get", v.Export())
 			}
@@ -239,6 +285,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("formnovalidate", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("#form_btn").get(0).formNoValidate()`); assert.NoError(t, err) {
 				assert.Equal(t, false, v.Export())
 			}
@@ -247,6 +296,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("formtarget", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("#form_btn").get(0).formTarget()`); assert.NoError(t, err) {
 				assert.Equal(t, "_self", v.Export())
 			}
@@ -255,6 +307,9 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("labels", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("#form_btn").get(0).labels()`); assert.NoError(t, err) {
 				assert.Equal(t, 1, len(v.Export().([]goja.Value)))
 				assert.Equal(t, "form_btn_label", v.Export().([]goja.Value)[0].Export().(LabelElement).Id())
@@ -266,29 +321,46 @@ func TestElements(t *testing.T) {
 			}
 		})
 		t.Run("name", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("#form_btn").get(0).name()`); assert.NoError(t, err) {
 				assert.Equal(t, "form_btn", v.Export())
 			}
 		})
 		t.Run("value", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("#form_btn_2").get(0).value()`); assert.NoError(t, err) {
 				assert.Equal(t, "form_btn_2_initval", v.Export())
 			}
 		})
 	})
 	t.Run("CanvasElement", func(t *testing.T) {
+		t.Parallel()
+
 		t.Run("width", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("canvas").get(0).width()`); assert.NoError(t, err) {
 				assert.Equal(t, int64(200), v.Export())
 			}
 		})
 		t.Run("height", func(t *testing.T) {
+			t.Parallel()
+			rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 			if v, err := rt.RunString(`doc.find("canvas").get(0).height()`); assert.NoError(t, err) {
 				assert.Equal(t, int64(150), v.Export())
 			}
 		})
 	})
 	t.Run("DataListElement options", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		if v, err := rt.RunString(`doc.find("datalist").get(0).options()`); assert.NoError(t, err) {
 			assert.Equal(t, 2, len(v.Export().([]goja.Value)))
 			assert.Equal(t, "dl_opt_1", v.Export().([]goja.Value)[0].Export().(OptionElement).Id())
@@ -296,6 +368,9 @@ func TestElements(t *testing.T) {
 		}
 	})
 	t.Run("FieldSetElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("elements", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("fieldset").get(0).elements()`); assert.NoError(t, err) {
 				assert.Equal(t, 5, len(v.Export().([]goja.Value)))
@@ -313,6 +388,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("FormElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("elements", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("#fieldset_form").get(0).elements()`); assert.NoError(t, err) {
 				assert.Equal(t, 6, len(v.Export().([]goja.Value)))
@@ -333,6 +411,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("InputElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("form", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("#test_dl_input").get(0).list().options()`); assert.NoError(t, err) {
 				assert.Equal(t, 2, len(v.Export().([]goja.Value)))
@@ -340,6 +421,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("LabelElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("control", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("#form_btn_2_label").get(0).control().value()`); assert.NoError(t, err) {
 				assert.Equal(t, "form_btn_2_initval", v.Export())
@@ -352,6 +436,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("LegendElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("form", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("#legend_1").get(0).form().id()`); assert.NoError(t, err) {
 				assert.Equal(t, "fieldset_form", v.Export())
@@ -359,6 +446,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("LinkElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("rel list", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("link").get(0).relList()`); assert.NoError(t, err) {
 				assert.Equal(t, []string{"alternate", "next"}, v.Export())
@@ -366,6 +456,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("MapElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("areas", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("#find_this_map").get(0).areas()`); assert.NoError(t, err) {
 				assert.Equal(t, 3, len(v.Export().([]goja.Value)))
@@ -378,6 +471,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("ObjectElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("form", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("#obj_1").get(0).form().id()`); assert.NoError(t, err) {
 				assert.Equal(t, "form1", v.Export())
@@ -385,6 +481,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("OptionElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("disabled", func(t *testing.T) {
 			v1, err1 := rt.RunString(`doc.find("#opt_1").get(0).disabled()`)
 			v2, err2 := rt.RunString(`doc.find("#opt_2").get(0).disabled()`)
@@ -431,6 +530,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("OutputElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("value", func(t *testing.T) {
 			v1, err1 := rt.RunString(`doc.find("#output1").get(0).value()`)
 			v2, err2 := rt.RunString(`doc.find("#output1").get(0).defaultValue()`)
@@ -446,6 +548,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("ProgressElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("max", func(t *testing.T) {
 			v1, err1 := rt.RunString(`doc.find("#progress1").get(0).max()`)
 			v2, err2 := rt.RunString(`doc.find("#progress2").get(0).max()`)
@@ -472,6 +577,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("ScriptElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("text", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("#script1").get(0).text()`); assert.NoError(t, err) {
 				assert.Equal(t, "script text", v.Export())
@@ -479,6 +587,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("SelectElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("form", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("#sel2").get(0).form().id()`); assert.NoError(t, err) {
 				assert.Equal(t, "form3", v.Export())
@@ -516,6 +627,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("StyleElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("text", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("#style1").get(0).type()`); assert.NoError(t, err) {
 				assert.Equal(t, "text/css", v.Export())
@@ -523,6 +637,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("TableElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("caption", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("table").get(0).caption().textContent()`); assert.NoError(t, err) {
 				assert.Equal(t, "caption text", v.Export())
@@ -617,6 +734,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("VideoElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("text tracks", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("#video1").get(0).textTracks()`); assert.NoError(t, err) {
 				assert.Equal(t, 2, len(v.Export().([]goja.Value)))
@@ -626,6 +746,9 @@ func TestElements(t *testing.T) {
 		})
 	})
 	t.Run("TitleElement", func(t *testing.T) {
+		t.Parallel()
+		rt := getTestRuntimeWithDoc(t, testHTMLElems)
+
 		t.Run("text tracks", func(t *testing.T) {
 			if v, err := rt.RunString(`doc.find("title").get(0).text()`); assert.NoError(t, err) {
 				assert.Equal(t, "titletest", v.Export())
