@@ -89,10 +89,17 @@ func (r *RootModule) NewModuleInstance(vu modules.VU) modules.Instance {
 	// wrappers (facades) that convert the old k6 idiosyncratic APIs to the new
 	// proper Client ones that accept Request objects and don't suck
 	mustExport("get", func(url goja.Value, args ...goja.Value) (*Response, error) {
-		args = append([]goja.Value{goja.Undefined()}, args...) // sigh
+		// http.get(url, params) doesn't have a body argument, so we add undefined
+		// as the third argument to http.request(method, url, body, params)
+		args = append([]goja.Value{goja.Undefined()}, args...)
 		return mi.defaultClient.Request(http.MethodGet, url, args...)
 	})
-	mustExport("head", mi.defaultClient.getMethodClosure(http.MethodHead))
+	mustExport("head", func(url goja.Value, args ...goja.Value) (*Response, error) {
+		// http.head(url, params) doesn't have a body argument, so we add undefined
+		// as the third argument to http.request(method, url, body, params)
+		args = append([]goja.Value{goja.Undefined()}, args...)
+		return mi.defaultClient.Request(http.MethodHead, url, args...)
+	})
 	mustExport("post", mi.defaultClient.getMethodClosure(http.MethodPost))
 	mustExport("put", mi.defaultClient.getMethodClosure(http.MethodPut))
 	mustExport("patch", mi.defaultClient.getMethodClosure(http.MethodPatch))
