@@ -37,10 +37,11 @@ import (
 
 	"go.k6.io/k6/lib/consts"
 	"go.k6.io/k6/lib/fsext"
-	"go.k6.io/k6/stats"
+	"go.k6.io/k6/metrics"
 )
 
 func TestNormalizeAndAnonymizePath(t *testing.T) {
+	t.Parallel()
 	testdata := map[string]string{
 		"/tmp":                            "/tmp",
 		"/tmp/myfile.txt":                 "/tmp/myfile.txt",
@@ -64,6 +65,7 @@ func TestNormalizeAndAnonymizePath(t *testing.T) {
 	for from, to := range testdata {
 		from, to := from, to
 		t.Run("path="+from, func(t *testing.T) {
+			t.Parallel()
 			res := NormalizeAndAnonymizePath(from)
 			assert.Equal(t, to, res)
 			assert.Equal(t, res, NormalizeAndAnonymizePath(res))
@@ -74,7 +76,7 @@ func TestNormalizeAndAnonymizePath(t *testing.T) {
 func makeMemMapFs(t *testing.T, input map[string][]byte) afero.Fs {
 	fs := afero.NewMemMapFs()
 	for path, data := range input {
-		require.NoError(t, afero.WriteFile(fs, path, data, 0644))
+		require.NoError(t, afero.WriteFile(fs, path, data, 0o644))
 	}
 	return fs
 }
@@ -104,7 +106,7 @@ func diffFilesystems(t *testing.T, first, second afero.Fs) {
 }
 
 func getInfoNames(infos []os.FileInfo) []string {
-	var names = make([]string, len(infos))
+	names := make([]string, len(infos))
 	for i, info := range infos {
 		names[i] = info.Name()
 	}
@@ -136,13 +138,15 @@ func diffFilesystemsDir(t *testing.T, first, second afero.Fs, dirname string) {
 }
 
 func TestArchiveReadWrite(t *testing.T) {
+	t.Parallel()
 	t.Run("Roundtrip", func(t *testing.T) {
+		t.Parallel()
 		arc1 := &Archive{
 			Type:      "js",
 			K6Version: consts.Version,
 			Options: Options{
 				VUs:        null.IntFrom(12345),
-				SystemTags: &stats.DefaultSystemTagSet,
+				SystemTags: &metrics.DefaultSystemTagSet,
 			},
 			FilenameURL: &url.URL{Scheme: "file", Path: "/path/to/a.js"},
 			Data:        []byte(`// a contents`),
@@ -181,6 +185,7 @@ func TestArchiveReadWrite(t *testing.T) {
 	})
 
 	t.Run("Anonymized", func(t *testing.T) {
+		t.Parallel()
 		testdata := []struct {
 			Pwd, PwdNormAnon string
 		}{
@@ -192,7 +197,7 @@ func TestArchiveReadWrite(t *testing.T) {
 				Type: "js",
 				Options: Options{
 					VUs:        null.IntFrom(12345),
-					SystemTags: &stats.DefaultSystemTagSet,
+					SystemTags: &metrics.DefaultSystemTagSet,
 				},
 				FilenameURL: &url.URL{Scheme: "file", Path: fmt.Sprintf("%s/a.js", entry.Pwd)},
 				K6Version:   consts.Version,
@@ -215,7 +220,7 @@ func TestArchiveReadWrite(t *testing.T) {
 				Type: "js",
 				Options: Options{
 					VUs:        null.IntFrom(12345),
-					SystemTags: &stats.DefaultSystemTagSet,
+					SystemTags: &metrics.DefaultSystemTagSet,
 				},
 				FilenameURL: &url.URL{Scheme: "file", Path: fmt.Sprintf("%s/a.js", entry.PwdNormAnon)},
 				K6Version:   consts.Version,
@@ -267,11 +272,12 @@ func TestArchiveJSONEscape(t *testing.T) {
 }
 
 func TestUsingCacheFromCacheOnReadFs(t *testing.T) {
-	var base = afero.NewMemMapFs()
-	var cached = afero.NewMemMapFs()
+	t.Parallel()
+	base := afero.NewMemMapFs()
+	cached := afero.NewMemMapFs()
 	// we specifically have different contents in both places
-	require.NoError(t, afero.WriteFile(base, "/wrong", []byte(`ooops`), 0644))
-	require.NoError(t, afero.WriteFile(cached, "/correct", []byte(`test`), 0644))
+	require.NoError(t, afero.WriteFile(base, "/wrong", []byte(`ooops`), 0o644))
+	require.NoError(t, afero.WriteFile(cached, "/correct", []byte(`test`), 0o644))
 
 	arc := &Archive{
 		Type:        "js",
@@ -318,9 +324,10 @@ func TestArchiveWithDataNotInFS(t *testing.T) {
 }
 
 func TestMalformedMetadata(t *testing.T) {
-	var fs = afero.NewMemMapFs()
-	require.NoError(t, afero.WriteFile(fs, "/metadata.json", []byte("{,}"), 0644))
-	var b, err = dumpMemMapFsToBuf(fs)
+	t.Parallel()
+	fs := afero.NewMemMapFs()
+	require.NoError(t, afero.WriteFile(fs, "/metadata.json", []byte("{,}"), 0o644))
+	b, err := dumpMemMapFsToBuf(fs)
 	require.NoError(t, err)
 	_, err = ReadArchive(b)
 	require.Error(t, err)
@@ -328,7 +335,8 @@ func TestMalformedMetadata(t *testing.T) {
 }
 
 func TestStrangePaths(t *testing.T) {
-	var pathsToChange = []string{
+	t.Parallel()
+	pathsToChange := []string{
 		`/path/with spaces/a.js`,
 		`/path/with spaces/a.js`,
 		`/path/with日本語/b.js`,
@@ -344,7 +352,7 @@ func TestStrangePaths(t *testing.T) {
 			K6Version: consts.Version,
 			Options: Options{
 				VUs:        null.IntFrom(12345),
-				SystemTags: &stats.DefaultSystemTagSet,
+				SystemTags: &metrics.DefaultSystemTagSet,
 			},
 			FilenameURL: &url.URL{Scheme: "file", Path: pathToChange},
 			Data:        []byte(`// ` + pathToChange + ` contents`),
@@ -376,9 +384,10 @@ func TestStrangePaths(t *testing.T) {
 }
 
 func TestStdinArchive(t *testing.T) {
-	var fs = afero.NewMemMapFs()
+	t.Parallel()
+	fs := afero.NewMemMapFs()
 	// we specifically have different contents in both places
-	require.NoError(t, afero.WriteFile(fs, "/-", []byte(`test`), 0644))
+	require.NoError(t, afero.WriteFile(fs, "/-", []byte(`test`), 0o644))
 
 	arc := &Archive{
 		Type:        "js",
@@ -400,5 +409,4 @@ func TestStdinArchive(t *testing.T) {
 	data, err := afero.ReadFile(newArc.Filesystems["file"], "/-")
 	require.NoError(t, err)
 	require.Equal(t, string(data), "test")
-
 }
