@@ -31,9 +31,8 @@ import (
 	"github.com/stretchr/testify/assert"
 	"gopkg.in/guregu/null.v3"
 
-	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/lib/netext/httpext"
-	"go.k6.io/k6/stats"
+	"go.k6.io/k6/metrics"
 )
 
 func TestSampleMarshaling(t *testing.T) {
@@ -54,7 +53,7 @@ func TestSampleMarshaling(t *testing.T) {
 				Data: &SampleDataSingle{
 					Type:  builtinMetrics.VUs.Type,
 					Time:  toMicroSecond(now),
-					Tags:  stats.IntoSampleTags(&map[string]string{"aaa": "bbb", "ccc": "123"}),
+					Tags:  metrics.IntoSampleTags(&map[string]string{"aaa": "bbb", "ccc": "123"}),
 					Value: 999,
 				},
 			},
@@ -66,11 +65,11 @@ func TestSampleMarshaling(t *testing.T) {
 				Metric: "iter_li_all",
 				Data: &SampleDataMap{
 					Time: toMicroSecond(now),
-					Tags: stats.IntoSampleTags(&map[string]string{"test": "mest"}),
+					Tags: metrics.IntoSampleTags(&map[string]string{"test": "mest"}),
 					Values: map[string]float64{
 						metrics.DataSentName:          1234.5,
 						metrics.DataReceivedName:      6789.1,
-						metrics.IterationDurationName: stats.D(10 * time.Second),
+						metrics.IterationDurationName: metrics.D(10 * time.Second),
 					},
 				},
 			},
@@ -108,7 +107,7 @@ func TestSampleMarshaling(t *testing.T) {
 				aggrData := &SampleDataAggregatedHTTPReqs{
 					Time: exptoMicroSecond,
 					Type: "aggregated_trend",
-					Tags: stats.IntoSampleTags(&map[string]string{"test": "mest"}),
+					Tags: metrics.IntoSampleTags(&map[string]string{"test": "mest"}),
 				}
 				aggrData.Add(
 					&httpext.Trail{
@@ -150,7 +149,7 @@ func TestSampleMarshaling(t *testing.T) {
 				aggrData := &SampleDataAggregatedHTTPReqs{
 					Time: exptoMicroSecond,
 					Type: "aggregated_trend",
-					Tags: stats.IntoSampleTags(&map[string]string{"test": "mest"}),
+					Tags: metrics.IntoSampleTags(&map[string]string{"test": "mest"}),
 				}
 				aggrData.Add(
 					&httpext.Trail{
@@ -218,9 +217,9 @@ func TestMetricAggregation(t *testing.T) {
 	m.Add(5 * time.Second)
 	m.Add(10 * time.Second)
 	m.Calc(5)
-	assert.Equal(t, m.Min, stats.D(1*time.Second))
-	assert.Equal(t, m.Max, stats.D(10*time.Second))
-	assert.Equal(t, m.Avg, stats.D(4*time.Second))
+	assert.Equal(t, m.Min, metrics.D(1*time.Second))
+	assert.Equal(t, m.Max, metrics.D(10*time.Second))
+	assert.Equal(t, m.Avg, metrics.D(4*time.Second))
 }
 
 // For more realistic request time distributions, import
