@@ -36,8 +36,8 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"go.k6.io/k6/lib/testutils"
+	"go.k6.io/k6/metrics"
 	"go.k6.io/k6/output"
-	"go.k6.io/k6/stats"
 )
 
 func TestBadConcurrentWrites(t *testing.T) {
@@ -108,10 +108,14 @@ func testOutputCycle(t testing.TB, handler http.HandlerFunc, body func(testing.T
 func TestOutput(t *testing.T) {
 	t.Parallel()
 
+	metric, err := metrics.NewRegistry().NewMetric("test_gauge", metrics.Gauge)
+	require.NoError(t, err)
+
 	var samplesRead int
 	defer func() {
 		require.Equal(t, samplesRead, 20)
 	}()
+
 	testOutputCycle(t, func(rw http.ResponseWriter, r *http.Request) {
 		b := bytes.NewBuffer(nil)
 		_, _ = io.Copy(b, r.Body)
@@ -127,12 +131,12 @@ func TestOutput(t *testing.T) {
 
 		rw.WriteHeader(204)
 	}, func(tb testing.TB, c *Output) {
-		samples := make(stats.Samples, 10)
+		samples := make(metrics.Samples, 10)
 		for i := 0; i < len(samples); i++ {
-			samples[i] = stats.Sample{
-				Metric: stats.New("testGauge", stats.Gauge),
+			samples[i] = metrics.Sample{
+				Metric: metric,
 				Time:   time.Now(),
-				Tags: stats.NewSampleTags(map[string]string{
+				Tags: metrics.NewSampleTags(map[string]string{
 					"something": "else",
 					"VU":        "21",
 					"else":      "something",
@@ -140,8 +144,8 @@ func TestOutput(t *testing.T) {
 				Value: 2.0,
 			}
 		}
-		c.AddMetricSamples([]stats.SampleContainer{samples})
-		c.AddMetricSamples([]stats.SampleContainer{samples})
+		c.AddMetricSamples([]metrics.SampleContainer{samples})
+		c.AddMetricSamples([]metrics.SampleContainer{samples})
 	})
 }
 
@@ -152,6 +156,7 @@ func TestOutputFlushMetricsConcurrency(t *testing.T) {
 		requests = int32(0)
 		block    = make(chan struct{})
 	)
+
 	wg := sync.WaitGroup{}
 	ts := httptest.NewServer(http.HandlerFunc(func(rw http.ResponseWriter, r *http.Request) {
 		// block all the received requests
@@ -170,6 +175,9 @@ func TestOutputFlushMetricsConcurrency(t *testing.T) {
 		ts.Close()
 	}()
 
+	metric, err := metrics.NewRegistry().NewMetric("test_gauge", metrics.Gauge)
+	require.NoError(t, err)
+
 	o, err := newOutput(output.Params{
 		Logger:         testutils.NewLogger(t),
 		ConfigArgument: ts.URL,
@@ -181,9 +189,9 @@ func TestOutputFlushMetricsConcurrency(t *testing.T) {
 		case o.semaphoreCh <- struct{}{}:
 			<-o.semaphoreCh
 			wg.Add(1)
-			o.AddMetricSamples([]stats.SampleContainer{stats.Samples{
-				stats.Sample{
-					Metric: stats.New("gauge", stats.Gauge),
+			o.AddMetricSamples([]metrics.SampleContainer{metrics.Samples{
+				metrics.Sample{
+					Metric: metric,
 					Value:  2.0,
 				},
 			}})
